/*

Copyright (C) 2002-2003, Jeffrey D. Argast.

The authors make NO WARRANTY or representation, either express or implied,
with respect to this software, its quality, accuracy, merchantability, or
fitness for a particular purpose.  This software is provided "AS IS", and you,
its user, assume the entire risk as to its quality and accuracy.

Permission is hereby granted to use, copy, modify, and distribute this
software or portions thereof for any purpose, without fee, subject to these
conditions:

(1) If any part of the source code is distributed, then this
statement must be included, with this copyright and no-warranty notice
unaltered.

(2) Permission for use of this software is granted only if the user accepts
full responsibility for any undesirable consequences; the authors accept
NO LIABILITY for damages of any kind.

*/


#import "NonCascadingWindow.h"

@implementation NonCascadingWindow

- (void) dealloc
{
	[fDefaultsFrameSizeName release];
	
	[super dealloc];
}

- (void) setDefaultsFrameName:(NSString*) defaultsFrameName
{
	fDefaultsFrameSizeName = [defaultsFrameName retain];
}

- (void)makeKeyAndOrderFront:(id)sender
{
 	NSString* revisionsFrame = [[NSUserDefaults standardUserDefaults]  objectForKey:fDefaultsFrameSizeName];
	
	[self setFrameFromString:revisionsFrame];

	NSRect myFrame = [self frame];
		
	// make sure we are actually visible
	NSArray* screens = [NSScreen screens];
	
	int n;
	int num = [screens count];
	
	BOOL viewIsHidden = YES;
	
	for ( n = 0; n < num; n++ )
	{
		NSScreen* aScreen = [screens objectAtIndex:n];
		
		NSRect screenFrame = [aScreen frame];
		
		NSRect intersectRect = NSIntersectionRect (myFrame, screenFrame);
		
		if ( !NSIsEmptyRect (intersectRect) )
		{
			viewIsHidden = NO;
		}
	}
	
	if ( viewIsHidden )
	{
		NSRect mainRect = [[NSScreen mainScreen] frame];
		
		myFrame.origin.x = mainRect.origin.x + 50;
		myFrame.origin.y = mainRect.origin.y + mainRect.size.height - myFrame.size.height - 50;
		
		[self setFrame:myFrame display:NO];
	}
	
	[super makeKeyAndOrderFront:sender];
}

- (void)orderOut:(id)sender
{
	NSString* revisionsFrame = [self stringWithSavedFrame];
	
	[[NSUserDefaults standardUserDefaults] setObject:revisionsFrame forKey:fDefaultsFrameSizeName];
	
	[super orderOut:sender];
}

@end
